projectal.dynamic_enums.skill_levels API documentation

# projectal.dynamic_enums.skill_levels

View Source

    1from projectal.dynamic_enum import DynamicEnum
    2
    3
    4class SkillLevels(DynamicEnum):
    5    _name = "SkillLevelEnum"

class SkillLevels(projectal.dynamic_enum.DynamicEnum): View Source

    5class SkillLevels(DynamicEnum):
    6    _name = "SkillLevelEnum"

##### Inherited Members

projectal.dynamic_enum.DynamicEnum
  get
  set